pub struct BusterBuilder<'a> { /* private fields */ }Expand description
Builder for Buster.
Implementations
Sourceimpl<'a> BusterBuilder<'a>
impl<'a> BusterBuilder<'a>
Sourcepub fn mime_types<VALUE: Into<Vec<Mime>>>(&mut self, value: VALUE) -> &mut Self
pub fn mime_types<VALUE: Into<Vec<Mime>>>(&mut self, value: VALUE) -> &mut Self
mime_types for hashing
Sourcepub fn result<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn result<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
directory for writing results
Sourcepub fn follow_links(&mut self, value: bool) -> &mut Self
pub fn follow_links(&mut self, value: bool) -> &mut Self
follow symlinks?
Sourcepub fn no_hash(&mut self, value: Vec<NoHashCategory<'a>>) -> &mut Self
pub fn no_hash(&mut self, value: Vec<NoHashCategory<'a>>) -> &mut Self
exclude these files for hashing. They will be copied over without including a hash in the filename Path should be relative to [self.source]